@@ -6,13 +6,14 @@ use strict;
 # use warnings; # 5.006 feature
 
 use vars qw($VERSION);
-$VERSION = '0.03_02';
+$VERSION = '0.11_02';
 
 $VERSION = eval $VERSION;
 
 use Log::Dispatch 2.01;
 use base qw(Log::Dispatch::Output);
 
+use Win32 ();
 use Win32::EventLog;
 
 use Params::Validate qw(validate SCALAR);
@@ -31,11 +32,17 @@ sub new {
     $self->_basic_init(%params);
     
     $self->{win32_source} = $params{source};
+    $self->{win32_log}    = "Application";
+
     if ($self->{win32_source} =~ /[\\]/) {
       die "Invalid characters in source";
     }
 
     if ($params{register}) {
+      unless (Win32::IsAdminUser) {
+	die "Admin user is required to register event sources";
+      }
+
       eval {
 	require Win32::EventLog::Message;
 	import Win32::EventLog::Message;
@@ -49,18 +56,19 @@ sub new {
             $params{register}, $params{source}
           );
 	  $self->{win32_register} = $params{register};
+	  $self->{win32_log}      = $params{source};
 	}
 	else {
 	  die "Invalid log";	  
 	}
       };
       if ($@) {
-	warn "Unable to register source to log $params{register}";
+	warn "Unable to register source to log $params{register}: $@";
       }
     }
 
     $self->{win32_handle} = Win32::EventLog->new(
-      $self->{win32_source}, Win32::NodeName
+      $self->{win32_log}, Win32::NodeName
     ) or die "Could not instaniate the event application";;
 
     return $self;
@@ -160,9 +168,9 @@ The source should not contain any backslash characters.
 
 =item register
 
-This specifies which event log to register the source with, if you
-want to register your source, or to post to a log other than the
-Application log.
+Registration of an event source removes the warning about the event
+being from an unknown source.  It also allows you to post to a log
+other than the Application log.
 
 When you register a source to particular log, all future events will
 be posted to that log, even if you unregister the source and attempt
@@ -176,15 +184,34 @@ will be tagged as "Audit Success" and higher levels will be tagged as
 In order to use this feature, you must have
 L<Win32::EventLog::Message> installed.
 
+The process that registers the event sources may need permission to
+register the event.  In some cases you may first need to run a simple
+script which registers the source name while logged in as an
+administrator:
+
+  use Log::Dispatch;
+  use Log::Dispatch::Win32EventLog 0.10;
+
+  my $dispatch = Log::Dispatch->new;
+  
+  $dispatch->add( Log::Dispatch::Win32EventLog->new(
+    source   => 'MySourceName',
+    register => 'System',
+  );
+
+afterwards the source name should be properly registered, and any
+script with rights to post to the event logs should be able to post.
+
+I<This is an experimental feature that may not work properly on all
+systems.>
+
 =item log_message
 
-inherited from Log::Dispatch::Output.
+inherited from L<Log::Dispatch::Output>.
 
 =back
 
-=head1 OTHER TOPICS
-
-=head1 Using with Log4perl
+=head2 Using with Log4perl
 
 This module can be used as a L<Log::Log4perl> appender.  The
 configuration file should have the following:
@@ -196,6 +223,20 @@ configuration file should have the following:
 
 Replace MySourceName with the source name of your application.
 
+=head1 KNOWN ISSUES
+
+See L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Log-Dispatch-Win32EventLog>
+for an up-to-date list of known issues and bugs.
+
+=head2 IIS and Windows Server 2003
+
+In some server configurations using IIS (Windows Server 2003), you may
+need to set security policy to grant permissions to write to the event
+log(s).
+
+See Microsoft KnowledgeBase Article 323076 at
+L<http://support.microsoft.com/default.aspx?scid=kb;en-us;323076>.
+
 =head1 SEE ALSO
 
 L<Log::Dispatch>, L<Win32::EventLog>, L<Log::Log4perl>
